Fix notification vibration demos in settings
While in zen mode, notification vibrations are ignored. These vibrations will also be ignored when attempting to demo the vibration intensity in settings.
Adding FLAG_BYPASS_INTERRUPTION_POLICY to the attributes of the vibration preview, to allow it to bypass the interruption policy and demo the vibration intensity as expected.
Fix: 301319836
Test: N/A
Change-Id: I240a896ff8e9516388a0238882db07f9680a184a
diff --git a/src/com/android/settings/accessibility/VibrationPreferenceConfig.java b/src/com/android/settings/accessibility/VibrationPreferenceConfig.java
index c25c38e..a304862 100644
--- a/src/com/android/settings/accessibility/VibrationPreferenceConfig.java
+++ b/src/com/android/settings/accessibility/VibrationPreferenceConfig.java
@@ -150,9 +150,13 @@
@VibrationAttributes.Usage int vibrationUsage) {
return new VibrationAttributes.Builder()
.setUsage(vibrationUsage)
- // Enforce fresh settings to be applied for the preview vibration, as they
- // are played immediately after the new user values are set.
- .setFlags(VibrationAttributes.FLAG_INVALIDATE_SETTINGS_CACHE)
+ .setFlags(
+ // Enforce fresh settings to be applied for the preview vibration, as they
+ // are played immediately after the new user values are set.
+ VibrationAttributes.FLAG_INVALIDATE_SETTINGS_CACHE
+ // Bypass user settings to allow vibration previews to be played while in
+ // limited interruptions' mode, e.g. zen mode.
+ | VibrationAttributes.FLAG_BYPASS_INTERRUPTION_POLICY)
.build();
}